@@ -21,11 +21,13 @@ class S3Client:
 
     @classmethod
     def create_client(cls, config: Config) -> Optional['S3Client']:
-        return cls(config) if config.has_aws else None
+        return cls(config) if config.has_s3 else None
 
     def send_report(self, local_html_file_path: str, remote_bucket_file_path: Optional[str] = None) -> bool:
-        report_filename = bucket_path.basename(remote_bucket_file_path) if remote_bucket_file_path else path.basename(local_html_file_path)
+        report_filename = bucket_path.basename(remote_bucket_file_path) if remote_bucket_file_path else path.basename(
+            local_html_file_path)
         bucket_report_path = remote_bucket_file_path if remote_bucket_file_path else report_filename
+        logger.info(f'Uploading to S3 bucket "{self.config.s3_bucket_name}"')
         try:
             self.client.upload_file(local_html_file_path, self.config.s3_bucket_name, bucket_report_path,
                                     ExtraArgs={'ContentType': 'text/html'})
@@ -38,6 +40,6 @@ class S3Client:
                 )
                 logger.info("Updated S3 bucket's website.")
         except botocore.exceptions.ClientError:
-            logger.error('Failed to upload report to S3.')
+            logger.exception('Failed to upload report to S3.')
             return False
         return True
