@@ -1,22 +1,92 @@
+from collections import defaultdict
 import json
 import os
-from typing import Dict, Optional, Union
+import statistics
+from typing import Dict, List, Optional, Union
 
 from elementary.clients.api.api import APIClient
-from elementary.monitor.api.models.schema import ExposureSchema, ModelCoverageSchema, ModelSchema, NormalizedExposureSchema, NormalizedModelSchema, NormalizedSourceSchema, SourceSchema
+from elementary.monitor.api.models.schema import (
+    ExposureSchema,
+    ModelCoverageSchema,
+    ModelRunSchema,
+    ModelRunsSchema,
+    ModelSchema,
+    NormalizedExposureSchema,
+    NormalizedModelSchema,
+    NormalizedSourceSchema,
+    SourceSchema,
+    TotalsModelRunsSchema
+)
 from elementary.utils.json_utils import try_load_json
+from elementary.utils.log import get_logger
+
+logger = get_logger(__name__)
 
 YAML_FILE_EXTENSION = ".yml"
 SQL_FILE_EXTENSION = ".sql"
 
 
 class ModelsAPI(APIClient):
+    def get_models_runs(self, days_back: Optional[int] = 7) -> List[ModelRunsSchema]:
+        run_operation_response = self.dbt_runner.run_operation(macro_name='get_models_runs',
+                                                               macro_args=dict(days_back=days_back))
+        model_run_dicts = json.loads(run_operation_response[0]) if run_operation_response else []
+        
+        models_runs = defaultdict(list)
+        for model_run in model_run_dicts:
+            models_runs[model_run['unique_id']].append(model_run)
+        
+        aggregated_models_runs = []
+        for model_unique_id, model_runs in models_runs.items():
+            totals = self._get_model_runs_totals(model_runs)
+            runs = [
+                ModelRunSchema(
+                    id=model_run['invocation_id'],
+                    time_utc=model_run['generated_at'],
+                    status=model_run['status'],
+                    full_refresh=model_run['full_refresh'],
+                    materialization=model_run['materialization'],
+                    execution_time=model_run['execution_time']
+                )
+                for model_run
+                in model_runs
+            ]
+            # The median should be based only on succesfull model runs.
+            successful_execution_times = [model_run['execution_time'] for model_run in model_runs if model_run['status'].lower() == 'success']
+            median_execution_time = statistics.median(successful_execution_times) if len(successful_execution_times) else 0
+            last_model_run = sorted(model_runs, key=lambda run: run['generated_at'])[-1]
+            execution_time_change_rate = (last_model_run['execution_time'] / median_execution_time - 1) * 100 if median_execution_time != 0 else 0
+            aggregated_models_runs.append(
+                ModelRunsSchema(
+                    unique_id=model_unique_id,
+                    schema=last_model_run['schema'],
+                    name=last_model_run['name'],
+                    status=last_model_run['status'],
+                    last_exec_time=last_model_run['execution_time'],
+                    compiled_sql=last_model_run['compiled_sql'],
+                    median_exec_time=median_execution_time,
+                    exec_time_change_rate=execution_time_change_rate,
+                    totals=totals,
+                    runs=runs
+                )
+            )
+        return aggregated_models_runs
+
+    @staticmethod
+    def _get_model_runs_totals(runs: List[dict]) -> TotalsModelRunsSchema:
+        error_runs = len([run for run in runs if run['status'] in ["error", "fail"]])
+        seccuss_runs = len([run for run in runs if run['status'] == "success"])
+        return TotalsModelRunsSchema(
+            errors=error_runs,
+            success=seccuss_runs
+        )
+
     def get_models(self) -> Dict[str, NormalizedModelSchema]:
         models_results = self.dbt_runner.run_operation(macro_name="get_models")
         models = dict()
         if models_results:
             for model_result in json.loads(models_results[0]):
-                model_data = ModelSchema(**model_result)
+                model_data = ModelSchema(**model_result, type='model')
                 normalized_model = ModelsAPI._normalize_dbt_artifact_dict(model_data, type="model")
                 model_unique_id = normalized_model.unique_id
                 models[model_unique_id] = normalized_model
@@ -27,7 +97,7 @@ class ModelsAPI(APIClient):
         sources = dict()
         if sources_results:
             for source_result in json.loads(sources_results[0]):
-                source_data = SourceSchema(**source_result)
+                source_data = SourceSchema(**source_result, type='source')
                 normalized_source = self._normalize_dbt_artifact_dict(source_data, type="source")
                 source_unique_id = normalized_source.unique_id
                 sources[source_unique_id] = normalized_source
@@ -38,7 +108,7 @@ class ModelsAPI(APIClient):
         exposures = dict()
         if exposures_results:
             for exposure_result in json.loads(exposures_results[0]):
-                exposure_data = ExposureSchema(**exposure_result)
+                exposure_data = ExposureSchema(**exposure_result, type='exposure')
                 normalized_exposure = self._normalize_dbt_artifact_dict(exposure_data, type="exposure")
                 exposure_unique_id = normalized_exposure.unique_id
                 exposures[exposure_unique_id] = normalized_exposure
